@@ -31,8 +31,10 @@ def get_destination_tables_with_schema(queries_config, query_name, schema_name,
 
 
 class DataSource:
-    def __init__(self, dbstream: DBStream, path_to_datasource_folder, schema_prefix=None, config_name='config',
-                 layer_type='datasource'):
+    def __init__(self, dbstream: DBStream, path_to_datasource_folder,
+                 schema_prefix=None,
+                 layer_type='datasource',
+                 loader_function=None):
         """
 
         :param dbstream:
@@ -41,12 +43,17 @@ class DataSource:
         self.dbstream = dbstream
         self.path_to_datasource_folder = path_to_datasource_folder
         self.schema_prefix = schema_prefix
-        self.config_name = config_name
         self.layer_type = layer_type
+        self.loader_function = loader_function
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
 
+    def load_file(self, path):
+        if self.loader_function is None:
+            return open(path).read()
+        return self.loader_function(path)
+
     def _create_beautiful_view(self, table_name, schema_name):
 
         result = self.dbstream.get_data_type(table_name=table_name, schema_name=schema_name)
@@ -78,7 +85,7 @@ class DataSource:
 
     def _get_query_list(self, layer_name, query_name=None):
         folder_path = self._build_folder_path(layer_name)
-        config = yaml.load(open(folder_path + ("%s.yaml" % self.config_name)), Loader=yaml.FullLoader)
+        config = yaml.load(self.load_file(folder_path + "config.yaml"), Loader=yaml.FullLoader)
         queries = config.get("queries")
         schema_name = config.get("schema_name") if config.get("schema_name") else (self.layer_type + "_" + layer_name)
         schema_name = self.schema_prefix + '_' + schema_name if self.schema_prefix else schema_name
@@ -96,7 +103,7 @@ class DataSource:
             query_template_file_name = query
         query_path = folder_path + "query/" + query_template_file_name + ".sql"
         query_params = query_config.get("query_params")
-        query_template = Template(open(query_path).read())
+        query_template = Template(self.load_file(query_path))
         table_name = query
         dict_params = dict()
         dict_params["TABLE_NAME"] = "%s.%s" % (schema_name, table_name)
@@ -114,7 +121,7 @@ class DataSource:
                 dict_params.update({params.upper(): value})
         dict_params.update(
             treat_all_snippet(
-                datasource_path=self.path_to_datasource_folder,
+                datasource_instance=self,
                 query_path=query_path,
                 layer=layer_name,
                 dict_params=dict_params)
@@ -123,7 +130,10 @@ class DataSource:
         return filled_query
 
     def compute(self, layer_name, query_name=None, environment="production"):
-        query_list, queries_config, schema_name, folder_path = self._get_query_list(layer_name, query_name=query_name)
+        query_list, queries_config, schema_name, folder_path = self._get_query_list(
+            layer_name=layer_name,
+            query_name=query_name
+        )
 
         for query in query_list:
             log_info("Layer: %s | Query started: %s | Environment: %s" % (layer_name, query, environment))
@@ -262,7 +272,7 @@ class DataSource:
 
     def function_compute(self, layer_name, environment='production'):
         def f():
-            self.compute(layer_name, environment)
+            self.compute(layer_name=layer_name, environment=environment)
 
         return f
 
